==> zio-aws-kinesisanalytics_2.13-5.17.123.1-sources.jar: zio/aws/kinesisanalytics/model/KinesisFirehoseInputDescription.scala <==
package zio.aws.kinesisanalytics.model
import zio.aws.kinesisanalytics.model.primitives.{RoleARN, ResourceARN}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class KinesisFirehoseInputDescription(
    resourceARN: Option[ResourceARN] = None,
    roleARN: Option[RoleARN] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription = {
    import KinesisFirehoseInputDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription
      .builder()
      .optionallyWith(
        resourceARN.map(value => ResourceARN.unwrap(value): java.lang.String)
      )(_.resourceARN)
      .optionallyWith(
        roleARN.map(value => RoleARN.unwrap(value): java.lang.String)
      )(_.roleARN)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription.ReadOnly =
    zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription
      .wrap(buildAwsValue())
}
object KinesisFirehoseInputDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription =
      zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription(
        resourceARN.map(value => value),
        roleARN.map(value => value)
      )
    def resourceARN: Option[ResourceARN]
    def roleARN: Option[RoleARN]
    def getResourceARN: ZIO[Any, AwsError, ResourceARN] =
      AwsError.unwrapOptionField("resourceARN", resourceARN)
    def getRoleARN: ZIO[Any, AwsError, RoleARN] =
      AwsError.unwrapOptionField("roleARN", roleARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription
  ) extends zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription.ReadOnly {
    override val resourceARN: Option[ResourceARN] = scala
      .Option(impl.resourceARN())
      .map(value =>
        zio.aws.kinesisanalytics.model.primitives.ResourceARN(value)
      )
    override val roleARN: Option[RoleARN] = scala
      .Option(impl.roleARN())
      .map(value => zio.aws.kinesisanalytics.model.primitives.RoleARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription
  ): zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisanalytics_2.13-5.19.7.6-sources.jar: zio/aws/kinesisanalytics/model/KinesisFirehoseInputDescription.scala <==
package zio.aws.kinesisanalytics.model
import zio.aws.kinesisanalytics.model.primitives.{RoleARN, ResourceARN}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class KinesisFirehoseInputDescription(
    resourceARN: Optional[ResourceARN] = Optional.Absent,
    roleARN: Optional[RoleARN] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription = {
    import KinesisFirehoseInputDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription
      .builder()
      .optionallyWith(
        resourceARN.map(value => ResourceARN.unwrap(value): java.lang.String)
      )(_.resourceARN)
      .optionallyWith(
        roleARN.map(value => RoleARN.unwrap(value): java.lang.String)
      )(_.roleARN)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription.ReadOnly =
    zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription
      .wrap(buildAwsValue())
}
object KinesisFirehoseInputDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription =
      zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription(
        resourceARN.map(value => value),
        roleARN.map(value => value)
      )
    def resourceARN: Optional[ResourceARN]
    def roleARN: Optional[RoleARN]
    def getResourceARN: ZIO[Any, AwsError, ResourceARN] =
      AwsError.unwrapOptionField("resourceARN", resourceARN)
    def getRoleARN: ZIO[Any, AwsError, RoleARN] =
      AwsError.unwrapOptionField("roleARN", roleARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription
  ) extends zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription.ReadOnly {
    override val resourceARN: Optional[ResourceARN] = zio.aws.core.internal
      .optionalFromNullable(impl.resourceARN())
      .map(value =>
        zio.aws.kinesisanalytics.model.primitives.ResourceARN(value)
      )
    override val roleARN: Optional[RoleARN] = zio.aws.core.internal
      .optionalFromNullable(impl.roleARN())
      .map(value => zio.aws.kinesisanalytics.model.primitives.RoleARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseInputDescription
  ): zio.aws.kinesisanalytics.model.KinesisFirehoseInputDescription.ReadOnly =
    new Wrapper(impl)
}
